@@ -57,6 +57,7 @@ int magnify = 0; /* [lc] */
 int user_screen = -1; /* preferred (by user) Xinerama screen */
 int browse = 0; /* scan directory of file for browsing */
 int autorotate = 0; /* autorotate JPEGs according to EXIF tag */
+int rotation = 0; /* rotation x degrees clockwise, 1=90degrees 2=180degrees 3=270degrees */
 
 #ifdef GTD_XINERAMA
 int number_xinerama_screens = 0;
@@ -84,8 +85,8 @@ const char *helpstrs[] =
     "a/A                  copy current image to .qiv-select",
     "d/D/del              move picture to .qiv-trash",
     "u                    undelete the previously trashed image",
-    "+/=                  zoom in (10%)",
-    "-                    zoom out (10%)",
+    "+/=/wheel r/btn fwd  zoom in (10%)",
+    "-/wheel l/btn back   zoom out (10%)",
     "e                    center mode on/off",
     "f                    fullscreen mode on/off",
     "m                    scale to screen size on/off",
@@ -164,6 +165,15 @@ const char *image_extensions[] = {
 #endif
 #ifdef EXTN_TGA
     ".tga",
+#endif
+#ifdef EXTN_ICO
+    ".ico",
+#endif
+#ifdef EXTN_WMF
+    ".wmf",
+#endif
+#ifdef EXTN_SVG
+    ".svg",
 #endif
     NULL
 };
@@ -194,6 +204,15 @@ const char *image_magic[] = {
 #endif
 #ifdef EXTN_TGA
   "Targa image data",
+#endif
+#ifdef EXTN_PCX
+  "PCX ver. 3.0 image",
+#endif
+#ifdef EXTN_SVG
+  "SVG Scalable Vector",
+#endif
+#ifdef EXTN_ICO
+  "MS Windows icon resource",
 #endif
  NULL
 };
