@@ -23,7 +23,7 @@
 extern char *optarg;
 extern int optind, opterr, optopt;
 
-static char *short_options = "ab:c:d:efg:hilmno:prstuvw:xyzA:BDF:GIMNPRSTW:X:";
+static char *short_options = "ab:c:d:efg:hilmno:pq:rstuvw:xyzA:BDF:GIMNPRSTW:X:";
 static struct option long_options[] =
 {
     {"do_grab",          0, NULL, 'a'},
@@ -35,11 +35,14 @@ static struct option long_options[] =
     {"gamma",            1, NULL, 'g'},
     {"help",             0, NULL, 'h'},
     {"no_statusbar",     0, NULL, 'i'},
+#if GDK_PIXBUF_MINOR >= 12
     {"autorotate",       0, NULL, 'l'},
+#endif
     {"maxpect",          0, NULL, 'm'},
     {"no_filter",        0, NULL, 'n'},
     {"bg_color",         1, NULL, 'o'},
     {"transparency",     0, NULL, 'p'},
+    {"rotation",         1, NULL, 'q'},
     {"random",           0, NULL, 'r'},
     {"slide",            0, NULL, 's'},
     {"scale_down",       0, NULL, 't'},
@@ -231,8 +234,10 @@ void options_read(int argc, char **argv, qiv_image *q)
             case 'h': show_help(argv[0], 0); break;
             case 'i': force_statusbar=0;
                 break;
+#if GDK_PIXBUF_MINOR >= 12
             case 'l': autorotate=1;
                 break;
+#endif
             case 'm': maxpect=1;
                 break;
             case 'n': filter=0;
@@ -241,6 +246,10 @@ void options_read(int argc, char **argv, qiv_image *q)
                 break;
             case 'p': transparency=1;
                 break;
+            case 'q': rotation=checked_atoi(optarg);
+                if ((rotation<0) || (rotation>3))
+                    usage(argv[0],1);
+                break;
             case 'r': random_order=1;
                 break;
             case 's': slide=1;
